@@ -22,6 +22,7 @@
 #include <QCoreApplication>
 #include <QDir>
 #include <QFile>
+#include <QSettings>
 #include <QStandardPaths>
 #include <QString>
 #include <QTextStream>
@@ -79,7 +80,7 @@ void Utility::setLaunchOnStartup(const QString &appName, const QString &guiName,
             return;
         }
 
-        auto autostartApplicationPath = []() {
+        auto autostartApplicationPath = []() -> QString {
             // $APPIMAGE will be set to the AppImage's path by the AppImage runtime
             // if it is set, we can assume to be run from within an AppImage
             // in that case, the desktop file should point to the AppImage rather than the
@@ -88,22 +89,37 @@ void Utility::setLaunchOnStartup(const QString &appName, const QString &guiName,
                 return Utility::appImageLocation();
             }
 
+            // we need to launch the client via its provided AppRun script (or at least source the AppRun hooks) to make sure it is displayed correctly
+            // if installed as a native package generated by linuxdeploy-plugin-native_packages, a linuxdeploy.conf file will be available that points to the
+            // location of the installed AppDir
+            QString linuxdeployConfPath = qApp->applicationDirPath() + QStringLiteral("/linuxdeploy.conf");
+
+            if (QFile(linuxdeployConfPath).exists()) {
+                QSettings linuxdeployConf(linuxdeployConfPath, QSettings::IniFormat);
+
+                const auto appdirInstallatedPath = linuxdeployConf.value(QStringLiteral("native_packages/appdir_installed_path"));
+                if (!appdirInstallatedPath.isNull()) {
+                    return appdirInstallatedPath.toString() + QStringLiteral("/AppRun");
+                }
+            }
+
+            // otherwise, we just use the application binary's own path, which should work for distribution-packaged installations and also for development
             return QCoreApplication::applicationFilePath();
         }();
 
         QTextStream ts(&iniFile);
-        ts.setCodec("UTF-8");
-        ts << QLatin1String("[Desktop Entry]") << endl
-           << QLatin1String("Name=") << guiName << endl
-           << QLatin1String("GenericName=") << QLatin1String("File Synchronizer") << endl
-           << QLatin1String("Exec=") << autostartApplicationPath << endl
-           << QLatin1String("Terminal=") << "false" << endl
-           << QLatin1String("Icon=") << appName.toLower() << endl // always use lowercase for icons
-           << QLatin1String("Categories=") << QLatin1String("Network") << endl
-           << QLatin1String("Type=") << QLatin1String("Application") << endl
-           << QLatin1String("StartupNotify=") << "false" << endl
-           << QLatin1String("X-GNOME-Autostart-enabled=") << "true" << endl
-           << QLatin1String("X-GNOME-Autostart-Delay=10") << endl;
+        ts.setEncoding(QStringConverter::Utf8);
+        ts << QLatin1String("[Desktop Entry]") << Qt::endl
+           << QLatin1String("Name=") << guiName << Qt::endl
+           << QLatin1String("GenericName=") << QLatin1String("File Synchronizer") << Qt::endl
+           << QLatin1String("Exec=") << autostartApplicationPath << Qt::endl
+           << QLatin1String("Terminal=") << "false" << Qt::endl
+           << QLatin1String("Icon=") << appName.toLower() << Qt::endl // always use lowercase for icons
+           << QLatin1String("Categories=") << QLatin1String("Network") << Qt::endl
+           << QLatin1String("Type=") << QLatin1String("Application") << Qt::endl
+           << QLatin1String("StartupNotify=") << "false" << Qt::endl
+           << QLatin1String("X-GNOME-Autostart-enabled=") << "true" << Qt::endl
+           << QLatin1String("X-GNOME-Autostart-Delay=10") << Qt::endl;
     } else {
         if (!QFile::remove(desktopFileLocation)) {
             qCWarning(lcUtility) << "Could not remove autostart desktop file";
