@@ -71,7 +71,7 @@ void HttpCredentialsGui::askFromUserAsync()
                 showDialog();
             } else {
                 qCWarning(lcHttpCredentialsGui) << "Bad http auth type:" << type;
-                emit asked();
+                emit fetched();
             }
         });
         job->start();
@@ -85,6 +85,10 @@ void HttpCredentialsGui::asyncAuthResult(OAuth::Result r, const QString &token,
     case OAuth::NotSupported:
         showDialog();
         return;
+    case OAuth::ErrorInsecureUrl:
+        // should not happen after the initial setup
+        Q_ASSERT(false);
+        [[fallthrough]];
     case OAuth::Error:
         Q_EMIT oAuthErrorOccurred();
         return;
@@ -96,7 +100,7 @@ void HttpCredentialsGui::asyncAuthResult(OAuth::Result r, const QString &token,
     _refreshToken = refreshToken;
     _ready = true;
     persist();
-    emit asked();
+    emit fetched();
 }
 
 void HttpCredentialsGui::showDialog()
@@ -110,7 +114,7 @@ void HttpCredentialsGui::showDialog()
     // make sure it's cleaned up since it's not owned by the account settings (also prevents memory leaks)
     dialog->setAttribute(Qt::WA_DeleteOnClose);
 
-    dialog->setTopLabelText(tr("Please enter your password to log in to your account."));
+    dialog->setTopLabelText(tr("Please enter your password to log in to the account %1.").arg(_account->displayName()));
 
     auto *contentWidget = qobject_cast<BasicLoginWidget *>(dialog->contentWidget());
     contentWidget->forceUsername(user());
@@ -127,7 +131,7 @@ void HttpCredentialsGui::showDialog()
         } else {
             Q_EMIT requestLogout();
         }
-        emit asked();
+        emit fetched();
     });
 
     dialog->open();
@@ -159,10 +163,8 @@ void HttpCredentialsGui::restartOAuth()
     _asyncAuth.reset(new AccountBasedOAuth(_account->sharedFromThis(), this));
     connect(_asyncAuth.data(), &OAuth::result,
         this, &HttpCredentialsGui::asyncAuthResult);
-    connect(_asyncAuth.data(), &OAuth::destroyed,
-        this, &HttpCredentialsGui::authorisationLinkChanged);
+    connect(_asyncAuth.data(), &OAuth::authorisationLinkChanged, this, &HttpCredentialsGui::authorisationLinkChanged);
     _asyncAuth->startAuthentication();
-    emit authorisationLinkChanged();
 }
 
 } // namespace OCC
