@@ -1,7 +1,10 @@
 import names
 import squish
 from os import path
-from helpers.SetupClientHelper import getCurrentUserSyncPath
+from helpers.SetupClientHelper import (
+    getCurrentUserSyncPath,
+    setCurrentUserSyncPath,
+)
 from helpers.ConfigHelper import get_config
 
 
@@ -47,6 +50,13 @@ class SyncConnectionWizard:
         "type": "QTreeWidget",
         "visible": 1,
     }
+    VFS_CHECKBOX = {
+        "text": "Use virtual files instead of downloading content immediately",
+        "type": "QCheckBox",
+        "unnamed": 1,
+        "visible": 1,
+        "window": names.add_Folder_Sync_Connection_OCC_FolderWizard,
+    }
     SELECTIVE_SYNC_TREE_HEADER = {
         "container": names.add_Folder_Sync_Connection_Deselect_remote_folders_you_do_not_wish_to_synchronize_QTreeWidget,
         "orientation": 1,
@@ -67,20 +77,25 @@ class SyncConnectionWizard:
     }
 
     @staticmethod
-    def setSyncPathInSyncConnectionWizardOc10():
+    def setSyncPathInSyncConnectionWizardOc10(sync_path=''):
         squish.waitForObject(SyncConnectionWizard.ADD_FOLDER_SYNC_CONNECTION_WIZARD)
-        squish.type(
-            SyncConnectionWizard.CHOOSE_LOCAL_SYNC_FOLDER,
-            getCurrentUserSyncPath(),
-        )
+        squish.waitForObject(SyncConnectionWizard.CHOOSE_LOCAL_SYNC_FOLDER).setText("")
+        if sync_path:
+            squish.type(SyncConnectionWizard.CHOOSE_LOCAL_SYNC_FOLDER, sync_path)
+            setCurrentUserSyncPath(sync_path)
+        else:
+            squish.type(
+                SyncConnectionWizard.CHOOSE_LOCAL_SYNC_FOLDER,
+                getCurrentUserSyncPath(),
+            )
         SyncConnectionWizard.nextStep()
 
     @staticmethod
-    def setSyncPathInSyncConnectionWizard(spaceName=''):
+    def setSyncPathInSyncConnectionWizard(sync_path=''):
         if get_config('ocis'):
-            SyncConnectionWizard.setSyncPathInSyncConnectionWizardOcis(spaceName)
+            SyncConnectionWizard.setSyncPathInSyncConnectionWizardOcis(sync_path)
         else:
-            SyncConnectionWizard.setSyncPathInSyncConnectionWizardOc10()
+            SyncConnectionWizard.setSyncPathInSyncConnectionWizardOc10(sync_path)
 
     @staticmethod
     def nextStep():
@@ -98,8 +113,7 @@ class SyncConnectionWizard:
         SyncConnectionWizard.nextStep()
 
     @staticmethod
-    def selectFoldersToSync(folders):
-        # first deselect all
+    def deselectAllRemoteFolders():
         squish.mouseClick(
             squish.waitForObject(SyncConnectionWizard.SELECTIVE_SYNC_ROOT_FOLDER),
             11,
@@ -107,16 +121,56 @@ class SyncConnectionWizard:
             squish.Qt.NoModifier,
             squish.Qt.LeftButton,
         )
+
+    @staticmethod
+    def enableOrDisableVfsSupport(action='disable'):
+        if not action in ['enable', 'disable']:
+            raise Exception("Invalid action: " + action)
+
+        checked = squish.waitForObjectExists(SyncConnectionWizard.VFS_CHECKBOX).checked
+        is_enable = action == 'enable'
+        if is_enable == checked:
+            return
+        squish.clickButton(squish.waitForObject(SyncConnectionWizard.VFS_CHECKBOX))
+
+    @staticmethod
+    def selectFoldersToSync(folders):
+        # first deselect all
+        SyncConnectionWizard.deselectAllRemoteFolders()
         for folder in folders:
-            # added a new key 'text' to dictionary SYNC_DIALOG_FOLDER_TREE
-            SyncConnectionWizard.SYNC_DIALOG_FOLDER_TREE['text'] = folder
-            squish.mouseClick(
-                squish.waitForObject(SyncConnectionWizard.SYNC_DIALOG_FOLDER_TREE),
-                11,
-                11,
-                squish.Qt.NoModifier,
-                squish.Qt.LeftButton,
-            )
+            folder_levels = folder.strip("/").split("/")
+            parent_selector = None
+            for sub_folder in folder_levels:
+                if not parent_selector:
+                    SyncConnectionWizard.SYNC_DIALOG_FOLDER_TREE['text'] = sub_folder
+                    parent_selector = SyncConnectionWizard.SYNC_DIALOG_FOLDER_TREE
+                    selector = parent_selector
+                else:
+                    selector = {
+                        "column": '0',
+                        "container": parent_selector,
+                        "text": sub_folder,
+                        "type": 'QModelIndex',
+                    }
+                if (
+                    len(folder_levels) == 1
+                    or folder_levels.index(sub_folder) == len(folder_levels) - 1
+                ):
+                    squish.mouseClick(
+                        squish.waitForObject(selector),
+                        11,
+                        11,
+                        squish.Qt.NoModifier,
+                        squish.Qt.LeftButton,
+                    )
+                else:
+                    squish.doubleClick(
+                        squish.waitForObject(selector),
+                        65,
+                        7,
+                        squish.Qt.NoModifier,
+                        squish.Qt.LeftButton,
+                    )
 
     @staticmethod
     def sortBy(headerText):
@@ -174,20 +228,26 @@ class SyncConnectionWizard:
         )
 
     @staticmethod
-    def setSyncPathInSyncConnectionWizardOcis(spaceName):
-        # override the default sync path
+    def setSyncPathInSyncConnectionWizardOcis(sync_path):
+        if not sync_path:
+            sync_path = path.join(
+                getCurrentUserSyncPath(), get_config("syncConnectionName")
+            )
         squish.type(
             squish.waitForObject(SyncConnectionWizard.CHOOSE_LOCAL_SYNC_FOLDER),
             "<Ctrl+A>",
         )
         squish.type(
             SyncConnectionWizard.CHOOSE_LOCAL_SYNC_FOLDER,
-            path.join(getCurrentUserSyncPath(), spaceName),
+            sync_path,
         )
+        SyncConnectionWizard.nextStep()
 
     @staticmethod
     def syncSpace(spaceName):
         SyncConnectionWizard.selectSpaceToSync(spaceName)
         SyncConnectionWizard.nextStep()
-        SyncConnectionWizard.setSyncPathInSyncConnectionWizard(spaceName)
+        SyncConnectionWizard.setSyncPathInSyncConnectionWizard(
+            path.join(getCurrentUserSyncPath(), spaceName)
+        )
         SyncConnectionWizard.addSyncConnection()
